from django.core.exceptions import ValidationError

import pytest


@pytest.mark.django_db
class TestOrganizationModel:
    def test_str(self, organization):
        assert str(organization) == "Organisation Test"

    def test_activities_display(self, organization):
        assert organization.display_activities() == "Activité Test"
        organization.activity.add('Activité Test 2')
        assert (
            organization.display_activities()
            == "Activité Test, Activité Test 2"
        )

    @pytest.mark.parametrize(
        'phone, correct',
        [
            ('+33 3 21 00 00 00', True),
            ('0321000000', True),
            ('+33 (1) 00 00 00', True),
            ('+33 3 21 a0 00 00', False),
            ('222', False),
            ('+33 3 21 00 00 00 00 00', False),
        ],
    )
    def test_phone_validation(self, phone, correct, organization):
        organization.phone = phone
        if correct:
            # Numéro correct, le full_clean passe
            organization.full_clean()
        else:
            # Numéro incorrect, une erreur est levée
            with pytest.raises(ValidationError):
                organization.full_clean()
