from django.urls import reverse_lazy

import pytest
from django_webtest import WebTest

from .factories import OrganizationFactory


class OrganizationFactoryHelperMixin:
    def _create_organizations(self):
        self.organization = OrganizationFactory.create(
            activities=[
                'Activité Test',
            ],
            inhabitant=False,
        )
        self.inhabitant = OrganizationFactory.create(
            activities=[
                'Activité Test',
            ],
            inhabitant=True,
            name="Habitant Test",
        )


@pytest.mark.django_db
class TestOrganizationListView(OrganizationFactoryHelperMixin, WebTest):
    url = reverse_lazy('annuaires:total')

    def test_inhabitants_and_organizations_display(self):
        self._create_organizations()
        resp = str(self.app.get(self.url).html)
        assert self.organization.name in resp
        assert self.inhabitant.name in resp


@pytest.mark.django_db
class TestInhabitantListView(OrganizationFactoryHelperMixin, WebTest):
    url = reverse_lazy('annuaires:inhabitants')

    def test_only_inhabitants_display(self):
        self._create_organizations()
        resp = str(self.app.get(self.url).html)
        assert self.organization.name not in resp
        assert self.inhabitant.name in resp
