from django.db import models

from wagtail.admin.edit_handlers import (
    FieldPanel,
    MultiFieldPanel,
    StreamFieldPanel,
)
from wagtail.core.fields import StreamField
from wagtail.core.models import Page
from wagtail.images.edit_handlers import ImageChooserPanel

from .blocks import BodyBlock


class AbstractBasePage(Page):
    """
    Modèle de base pour les pages du site
    """

    banner = models.ForeignKey(
        'wagtailimages.Image',
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
        verbose_name="bannière",
        help_text=(
            "Une image utilisée comme bannière de fond pour le titre. La "
            "résolution doit être assez grande pour garantir une bonne "
            "qualité d'affichage."
        ),
    )

    header_panels = [FieldPanel('title'), ImageChooserPanel('banner')]

    content_panels = [
        MultiFieldPanel(header_panels, heading="Entête"),
    ]

    class Meta:
        abstract = True


class StandardPage(AbstractBasePage):
    """
    Une page standard avec du contenu.
    """

    body = StreamField(BodyBlock(), verbose_name="contenu")

    class Meta:
        verbose_name = "page standard"
        verbose_name_plural = "pages standards"

    show_in_menus_default = True

    content_panels = AbstractBasePage.content_panels + [
        StreamFieldPanel('body'),
    ]
